stravalib.client.Client.get\_athlete\_starred\_segments
=======================================================

.. currentmodule:: stravalib.client

.. automethod:: Client.get_athlete_starred_segments
